import { NoopLogger, DefaultLogger } from '../index.mjs';
import { M as MySqlSession, a as MySqlTransaction, P as PreparedQuery$1, b as MySqlDatabase, c as MySqlDialect } from '../session-ee50e69e.mjs';
import { e as entityKind, f as fillPlaceholders, m as mapResultRow, a as extractTablesRelationalConfig, c as createTableRelationsHelpers } from '../alias-f3b5fd3d.mjs';
import 'mysql2/promise';

class MySqlRemoteSession extends MySqlSession {
    client;
    schema;
    static [entityKind] = 'MySqlRemoteSession';
    logger;
    constructor(client, dialect, schema, options) {
        super(dialect);
        this.client = client;
        this.schema = schema;
        this.logger = options.logger ?? new NoopLogger();
    }
    prepareQuery(query, fields, customResultMapper) {
        return new PreparedQuery(this.client, query.sql, query.params, this.logger, fields, customResultMapper);
    }
    all(query) {
        const querySql = this.dialect.sqlToQuery(query);
        this.logger.logQuery(querySql.sql, querySql.params);
        return this.client(querySql.sql, querySql.params, 'all').then(({ rows }) => rows);
    }
    async transaction(_transaction, _config) {
        throw new Error('Transactions are not supported by the MySql Proxy driver');
    }
}
class MySqlProxyTransaction extends MySqlTransaction {
    static [entityKind] = 'MySqlProxyTransaction';
    async transaction(_transaction) {
        throw new Error('Transactions are not supported by the MySql Proxy driver');
    }
}
class PreparedQuery extends PreparedQuery$1 {
    client;
    queryString;
    params;
    logger;
    fields;
    customResultMapper;
    static [entityKind] = 'MySqlProxyPreparedQuery';
    constructor(client, queryString, params, logger, fields, customResultMapper) {
        super();
        this.client = client;
        this.queryString = queryString;
        this.params = params;
        this.logger = logger;
        this.fields = fields;
        this.customResultMapper = customResultMapper;
    }
    async execute(placeholderValues = {}) {
        const params = fillPlaceholders(this.params, placeholderValues);
        const { fields, client, queryString, logger, joinsNotNullableMap, customResultMapper } = this;
        logger.logQuery(queryString, params);
        if (!fields && !customResultMapper) {
            const { rows } = await client(queryString, params, 'execute');
            return rows;
        }
        const { rows } = await client(queryString, params, 'all');
        if (customResultMapper) {
            return customResultMapper(rows);
        }
        return rows.map((row) => mapResultRow(fields, row, joinsNotNullableMap));
    }
    iterator(_placeholderValues = {}) {
        throw new Error('Streaming is not supported by the MySql Proxy driver');
    }
}

function drizzle(callback, config = {}) {
    const dialect = new MySqlDialect();
    let logger;
    if (config.logger === true) {
        logger = new DefaultLogger();
    }
    else if (config.logger !== false) {
        logger = config.logger;
    }
    let schema;
    if (config.schema) {
        const tablesConfig = extractTablesRelationalConfig(config.schema, createTableRelationsHelpers);
        schema = {
            fullSchema: config.schema,
            schema: tablesConfig.tables,
            tableNamesMap: tablesConfig.tableNamesMap,
        };
    }
    const session = new MySqlRemoteSession(callback, dialect, schema, { logger });
    return new MySqlDatabase(dialect, session, schema, 'default');
}

export { MySqlProxyTransaction, MySqlRemoteSession, PreparedQuery, drizzle };
//# sourceMappingURL=index.mjs.map
