'use strict';

var index = require('../index.cjs');
var session = require('../session-1c5c4449.cjs');
var alias = require('../alias-aa343af5.cjs');

class PgRemoteSession extends session.PgSession {
    client;
    schema;
    static [alias.entityKind] = 'PgRemoteSession';
    logger;
    constructor(client, dialect, schema, options = {}) {
        super(dialect);
        this.client = client;
        this.schema = schema;
        this.logger = options.logger ?? new index.NoopLogger();
    }
    prepareQuery(query, fields, name, customResultMapper) {
        return new PreparedQuery(this.client, query.sql, query.params, this.logger, fields, customResultMapper);
    }
    async transaction(_transaction, _config) {
        throw new Error('Transactions are not supported by the Postgres Proxy driver');
    }
}
class PgProxyTransaction extends session.PgTransaction {
    static [alias.entityKind] = 'PgProxyTransaction';
    async transaction(_transaction) {
        throw new Error('Transactions are not supported by the Postgres Proxy driver');
    }
}
class PreparedQuery extends session.PreparedQuery {
    client;
    queryString;
    params;
    logger;
    fields;
    customResultMapper;
    static [alias.entityKind] = 'PgProxyPreparedQuery';
    constructor(client, queryString, params, logger, fields, customResultMapper) {
        super();
        this.client = client;
        this.queryString = queryString;
        this.params = params;
        this.logger = logger;
        this.fields = fields;
        this.customResultMapper = customResultMapper;
    }
    async execute(placeholderValues = {}) {
        return alias.tracer.startActiveSpan('drizzle.execute', async (span) => {
            const params = alias.fillPlaceholders(this.params, placeholderValues);
            const { fields, client, queryString, joinsNotNullableMap, customResultMapper, logger } = this;
            span?.setAttributes({
                'drizzle.query.text': queryString,
                'drizzle.query.params': JSON.stringify(params),
            });
            logger.logQuery(queryString, params);
            if (!fields && !customResultMapper) {
                return alias.tracer.startActiveSpan('drizzle.driver.execute', async () => {
                    const { rows } = await client(queryString, params, 'execute');
                    return rows;
                });
            }
            const rows = await alias.tracer.startActiveSpan('drizzle.driver.execute', async () => {
                span?.setAttributes({
                    'drizzle.query.text': queryString,
                    'drizzle.query.params': JSON.stringify(params),
                });
                const { rows } = await client(queryString, params, 'all');
                return rows;
            });
            return alias.tracer.startActiveSpan('drizzle.mapResponse', () => {
                return customResultMapper
                    ? customResultMapper(rows)
                    : rows.map((row) => alias.mapResultRow(fields, row, joinsNotNullableMap));
            });
        });
    }
    async all() { }
}

function drizzle(callback, config = {}) {
    const dialect = new alias.PgDialect();
    let logger;
    if (config.logger === true) {
        logger = new index.DefaultLogger();
    }
    else if (config.logger !== false) {
        logger = config.logger;
    }
    let schema;
    if (config.schema) {
        const tablesConfig = alias.extractTablesRelationalConfig(config.schema, alias.createTableRelationsHelpers);
        schema = {
            fullSchema: config.schema,
            schema: tablesConfig.tables,
            tableNamesMap: tablesConfig.tableNamesMap,
        };
    }
    const session$1 = new PgRemoteSession(callback, dialect, schema, { logger });
    return new session.PgDatabase(dialect, session$1, schema);
}

exports.PgProxyTransaction = PgProxyTransaction;
exports.PgRemoteSession = PgRemoteSession;
exports.PreparedQuery = PreparedQuery;
exports.drizzle = drizzle;
//# sourceMappingURL=index.cjs.map
