import { NoopLogger, DefaultLogger } from '../index.mjs';
import { a as PgSession, b as PgTransaction, P as PreparedQuery$1, c as PgDatabase } from '../session-081c7796.mjs';
import { e as entityKind, t as tracer, f as fillPlaceholders, m as mapResultRow, a as extractTablesRelationalConfig, c as createTableRelationsHelpers, P as PgDialect } from '../alias-f3b5fd3d.mjs';

class PgRemoteSession extends PgSession {
    client;
    schema;
    static [entityKind] = 'PgRemoteSession';
    logger;
    constructor(client, dialect, schema, options = {}) {
        super(dialect);
        this.client = client;
        this.schema = schema;
        this.logger = options.logger ?? new NoopLogger();
    }
    prepareQuery(query, fields, name, customResultMapper) {
        return new PreparedQuery(this.client, query.sql, query.params, this.logger, fields, customResultMapper);
    }
    async transaction(_transaction, _config) {
        throw new Error('Transactions are not supported by the Postgres Proxy driver');
    }
}
class PgProxyTransaction extends PgTransaction {
    static [entityKind] = 'PgProxyTransaction';
    async transaction(_transaction) {
        throw new Error('Transactions are not supported by the Postgres Proxy driver');
    }
}
class PreparedQuery extends PreparedQuery$1 {
    client;
    queryString;
    params;
    logger;
    fields;
    customResultMapper;
    static [entityKind] = 'PgProxyPreparedQuery';
    constructor(client, queryString, params, logger, fields, customResultMapper) {
        super();
        this.client = client;
        this.queryString = queryString;
        this.params = params;
        this.logger = logger;
        this.fields = fields;
        this.customResultMapper = customResultMapper;
    }
    async execute(placeholderValues = {}) {
        return tracer.startActiveSpan('drizzle.execute', async (span) => {
            const params = fillPlaceholders(this.params, placeholderValues);
            const { fields, client, queryString, joinsNotNullableMap, customResultMapper, logger } = this;
            span?.setAttributes({
                'drizzle.query.text': queryString,
                'drizzle.query.params': JSON.stringify(params),
            });
            logger.logQuery(queryString, params);
            if (!fields && !customResultMapper) {
                return tracer.startActiveSpan('drizzle.driver.execute', async () => {
                    const { rows } = await client(queryString, params, 'execute');
                    return rows;
                });
            }
            const rows = await tracer.startActiveSpan('drizzle.driver.execute', async () => {
                span?.setAttributes({
                    'drizzle.query.text': queryString,
                    'drizzle.query.params': JSON.stringify(params),
                });
                const { rows } = await client(queryString, params, 'all');
                return rows;
            });
            return tracer.startActiveSpan('drizzle.mapResponse', () => {
                return customResultMapper
                    ? customResultMapper(rows)
                    : rows.map((row) => mapResultRow(fields, row, joinsNotNullableMap));
            });
        });
    }
    async all() { }
}

function drizzle(callback, config = {}) {
    const dialect = new PgDialect();
    let logger;
    if (config.logger === true) {
        logger = new DefaultLogger();
    }
    else if (config.logger !== false) {
        logger = config.logger;
    }
    let schema;
    if (config.schema) {
        const tablesConfig = extractTablesRelationalConfig(config.schema, createTableRelationsHelpers);
        schema = {
            fullSchema: config.schema,
            schema: tablesConfig.tables,
            tableNamesMap: tablesConfig.tableNamesMap,
        };
    }
    const session = new PgRemoteSession(callback, dialect, schema, { logger });
    return new PgDatabase(dialect, session, schema);
}

export { PgProxyTransaction, PgRemoteSession, PreparedQuery, drizzle };
//# sourceMappingURL=index.mjs.map
